@@ -15,6 +15,8 @@ from urllib.parse import urljoin
 import warnings
 
 import requests
+from requests import Response
+from requests.utils import parse_header_links
 
 from swh.core.config import load_from_envvar
 from swh.deposit import __version__ as swh_deposit_version
@@ -157,7 +159,7 @@ class PrivateApiDepositClient(BaseApiDepositClient):
 
     """
 
-    def archive_get(self, archive_update_url, archive):
+    def archive_get(self, archive_update_url: str, archive: str) -> Optional[str]:
         """Retrieve the archive from the deposit to a local directory.
 
         Args:
@@ -172,10 +174,10 @@ class PrivateApiDepositClient(BaseApiDepositClient):
             Or None if any problem arose.
 
         """
-        r = self.do("get", archive_update_url, stream=True)
-        if r.ok:
+        response = self.do("get", archive_update_url, stream=True)
+        if response.ok:
             with open(archive, "wb") as f:
-                for chunk in r.iter_content():
+                for chunk in response.iter_content():
                     f.write(chunk)
 
             return archive
@@ -272,7 +274,9 @@ class BaseDepositClient(BaseApiDepositClient):
         """Http method to use on the url"""
         raise NotImplementedError
 
-    def parse_result_ok(self, xml_content):
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
         """Given an xml result from the api endpoint, parse it and returns a
            dict.
 
@@ -286,7 +290,7 @@ class BaseDepositClient(BaseApiDepositClient):
         """
         return {}
 
-    def parse_result_error(self, xml_content: bytes) -> Dict:
+    def parse_result_error(self, xml_content: str) -> Dict[str, Any]:
         """Given an error response in xml, parse it into a dict.
 
         Returns:
@@ -304,15 +308,18 @@ class BaseDepositClient(BaseApiDepositClient):
             "sword:verboseDescription": sword_error.get("sword:verboseDescription", ""),
         }
 
-    def do_execute(self, method, url, info):
+    def do_execute(self, method: str, url: str, info: Dict, **kwargs) -> Response:
         """Execute the http query to url using method and info information.
 
-        By default, execute a simple query to url with the http
-        method.  Override this in daughter class to improve the
-        default behavior if needed.
+        By default, execute a simple query to url with the http method. Override this in
+        subclass to improve the default behavior if needed.
 
         """
-        return self.do(method, url)
+        return self.do(method, url, **kwargs)
+
+    def compute_params(self, **kwargs) -> Dict[str, Any]:
+        """Determine the params out of the kwargs"""
+        return {}
 
     def execute(self, *args, **kwargs) -> Dict[str, Any]:
         """Main endpoint to prepare and execute the http query to the api.
@@ -327,34 +334,36 @@ class BaseDepositClient(BaseApiDepositClient):
         url = self.compute_url(*args, **kwargs)
         method = self.compute_method(*args, **kwargs)
         info = self.compute_information(*args, **kwargs)
+        params = self.compute_params(**kwargs)
 
         try:
-            r = self.do_execute(method, url, info)
+            response = self.do_execute(method, url, info, params=params)
         except Exception as e:
             msg = self.error_msg % (url, e)
-            r = self.empty_result
-            r.update(
+            result = self.empty_result
+            result.update(
                 {"error": msg,}
             )
-            return r
+            return result
         else:
-            if r.ok:
-                if int(r.status_code) == 204:  # 204 returns no body
-                    return {"status": r.status_code}
+            if response.ok:
+                if int(response.status_code) == 204:  # 204 returns no body
+                    return {"status": response.status_code}
                 else:
-                    return self.parse_result_ok(r.text)
+                    headers = dict(response.headers) if response.headers else None
+                    return self.parse_result_ok(response.text, headers)
             else:
-                error = self.parse_result_error(r.text)
+                error = self.parse_result_error(response.text)
                 empty = self.empty_result
                 error.update(empty)
-                if r.status_code == 503:
+                if response.status_code == 503:
                     summary = error.get("summary")
                     detail = error.get("sword:verboseDescription")
                     # Maintenance error
                     if summary and detail:
                         raise MaintenanceError(f"{summary}: {detail}")
                 error.update(
-                    {"status": r.status_code,}
+                    {"status": response.status_code,}
                 )
                 return error
 
@@ -379,13 +388,15 @@ class ServiceDocumentDepositClient(BaseDepositClient):
     def compute_method(self, *args, **kwargs):
         return "get"
 
-    def parse_result_ok(self, xml_content):
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
         """Parse service document's success response.
 
         """
         return parse_xml(xml_content)
 
-    def parse_result_error(self, xml_content: bytes) -> Dict:
+    def parse_result_error(self, xml_content: str) -> Dict[str, Any]:
         result = super().parse_result_error(xml_content)
         return {"error": result["summary"]}
 
@@ -414,7 +425,9 @@ class StatusDepositClient(BaseDepositClient):
     def compute_method(self, *args, **kwargs):
         return "get"
 
-    def parse_result_ok(self, xml_content):
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
         """Given an xml content as string, returns a deposit dict.
 
         """
@@ -430,6 +443,72 @@ class StatusDepositClient(BaseDepositClient):
         return {key: data.get("swh:" + key) for key in keys}
 
 
+class CollectionListDepositClient(BaseDepositClient):
+    """List a collection of deposits (owned by a user)
+
+    """
+
+    def __init__(self, config=None, url=None, auth=None):
+        super().__init__(
+            url=url,
+            auth=auth,
+            config=config,
+            error_msg="List deposits failure at %s: %s",
+            empty_result={},
+        )
+
+    def compute_url(self, collection, **kwargs):
+        return f"/{collection}/"
+
+    def compute_method(self, *args, **kwargs):
+        return "get"
+
+    def compute_params(self, **kwargs) -> Dict[str, Any]:
+        """Transmit pagination params if values provided are not None
+        (e.g. page, page_size)
+
+        """
+        return {k: v for k, v in kwargs.items() if v is not None}
+
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
+        """Given an xml content as string, returns a deposit dict.
+
+        """
+        link_header = headers.get("Link", "") if headers else ""
+        links = parse_header_links(link_header)
+        data = parse_xml(xml_content)["atom:feed"]
+        total_result = data.get("swh:count", 0)
+        keys = [
+            "id",
+            "reception_date",
+            "complete_date",
+            "external_id",
+            "swhid",
+            "status",
+            "status_detail",
+            "swhid_context",
+            "origin_url",
+        ]
+        entries_ = data.get("atom:entry", [])
+        entries = [entries_] if isinstance(entries_, dict) else entries_
+        deposits_d = [
+            {
+                key: deposit.get(f"swh:{key}")
+                for key in keys
+                if deposit.get(f"swh:{key}") is not None
+            }
+            for deposit in entries
+        ]
+
+        return {
+            "count": total_result,
+            "deposits": deposits_d,
+            **{entry["rel"]: entry["url"] for entry in links},
+        }
+
+
 class BaseCreateDepositClient(BaseDepositClient):
     """Deposit client base class to post new deposit.
 
@@ -450,7 +529,9 @@ class BaseCreateDepositClient(BaseDepositClient):
     def compute_method(self, *args, **kwargs):
         return "post"
 
-    def parse_result_ok(self, xml_content):
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
         """Given an xml content as string, returns a deposit dict.
 
         """
@@ -466,7 +547,7 @@ class BaseCreateDepositClient(BaseDepositClient):
     def compute_headers(self, info: Dict[str, Any]) -> Dict[str, Any]:
         return info
 
-    def do_execute(self, method, url, info):
+    def do_execute(self, method, url, info, **kwargs):
         with open(info["filepath"], "rb") as f:
             return self.do(method, url, data=f, headers=info["headers"])
 
@@ -558,7 +639,9 @@ class CreateMetadataOnlyDepositClient(BaseCreateDepositClient):
             "filepath": kwargs["metadata_path"],
         }
 
-    def parse_result_ok(self, xml_content):
+    def parse_result_ok(
+        self, xml_content: str, headers: Optional[Dict] = None
+    ) -> Dict[str, Any]:
         """Given an xml content as string, returns a deposit dict.
 
         """
@@ -607,7 +690,7 @@ class CreateMultipartDepositClient(BaseCreateDepositClient):
         files, headers = self._multipart_info(info, info_meta)
         return {"files": files, "headers": headers}
 
-    def do_execute(self, method, url, info):
+    def do_execute(self, method, url, info, **kwargs):
         return self.do(method, url, files=info["files"], headers=info["headers"])
 
 
@@ -634,6 +717,17 @@ class PublicApiDepositClient(BaseApiDepositClient):
             collection, deposit_id
         )
 
+    def deposit_list(
+        self,
+        collection: str,
+        page: Optional[int] = None,
+        page_size: Optional[int] = None,
+    ):
+        """List deposits from the collection"""
+        return CollectionListDepositClient(url=self.base_url, auth=self.auth).execute(
+            collection, page=page, page_size=page_size
+        )
+
     def deposit_create(
         self,
         collection: str,
@@ -674,11 +768,11 @@ class PublicApiDepositClient(BaseApiDepositClient):
         swhid: Optional[str] = None,
     ):
         """Update (add/replace) existing deposit (archive, metadata, both)."""
-        r = self.deposit_status(collection, deposit_id)
-        if "error" in r:
-            return r
+        response = self.deposit_status(collection, deposit_id)
+        if "error" in response:
+            return response
 
-        status = r["deposit_status"]
+        status = response["deposit_status"]
         if swhid is None and status != "partial":
             return {
                 "error": "You can only act on deposit with status 'partial'",
@@ -694,7 +788,9 @@ class PublicApiDepositClient(BaseApiDepositClient):
                 "deposit_id": deposit_id,
             }
         if archive and not metadata:
-            r = UpdateArchiveDepositClient(url=self.base_url, auth=self.auth).execute(
+            result = UpdateArchiveDepositClient(
+                url=self.base_url, auth=self.auth
+            ).execute(
                 collection,
                 in_progress,
                 slug,
@@ -703,7 +799,7 @@ class PublicApiDepositClient(BaseApiDepositClient):
                 replace=replace,
             )
         elif not archive and metadata and swhid is None:
-            r = UpdateMetadataOnPartialDepositClient(
+            result = UpdateMetadataOnPartialDepositClient(
                 url=self.base_url, auth=self.auth
             ).execute(
                 collection,
@@ -714,7 +810,7 @@ class PublicApiDepositClient(BaseApiDepositClient):
                 replace=replace,
             )
         elif not archive and metadata and swhid is not None:
-            r = UpdateMetadataOnDoneDepositClient(
+            result = UpdateMetadataOnDoneDepositClient(
                 url=self.base_url, auth=self.auth
             ).execute(
                 collection,
@@ -725,7 +821,9 @@ class PublicApiDepositClient(BaseApiDepositClient):
                 swhid=swhid,
             )
         else:
-            r = UpdateMultipartDepositClient(url=self.base_url, auth=self.auth).execute(
+            result = UpdateMultipartDepositClient(
+                url=self.base_url, auth=self.auth
+            ).execute(
                 collection,
                 in_progress,
                 slug,
@@ -735,8 +833,8 @@ class PublicApiDepositClient(BaseApiDepositClient):
                 replace=replace,
             )
 
-        if "error" in r:
-            return r
+        if "error" in result:
+            return result
         return self.deposit_status(collection, deposit_id)
 
     def deposit_metadata_only(
