@@ -111,14 +111,8 @@ class APIConfig:
 
     def swh_deposit_authority(self):
         return MetadataAuthority(
-            type=MetadataAuthorityType.REGISTRY,
-            url=self.config["swh_authority_url"],
-            metadata={},
+            type=MetadataAuthorityType.REGISTRY, url=self.config["swh_authority_url"],
         )
 
     def swh_deposit_fetcher(self):
-        return MetadataFetcher(
-            name=self.tool["name"],
-            version=self.tool["version"],
-            metadata=self.tool["configuration"],
-        )
+        return MetadataFetcher(name=self.tool["name"], version=self.tool["version"],)
